==> ant-design-vue-2.1.3.jar: META-INF/resources/webjars/ant-design-vue/2.1.3/lib/date-picker/index.d.ts <==
import { DefineComponent, Plugin } from 'vue';
import { RangePickerPropsTypes, MonthPickerPropsTypes, WeekPickerPropsTypes } from './interface';
declare const _default: {
    new (...args: any[]): {
        $: import("vue").ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            locale: any;
        }> & Omit<Readonly<{
            locale: any;
        } & {
            value?: string | import("moment").Moment;
            onFocus?: EventHandlerNonNull;
            onBlur?: EventHandlerNonNull;
            onChange?: (date: import("moment").Moment, dateString: string) => void;
            prefixCls?: string;
            size?: "default" | "small" | "large";
            open?: boolean;
            disabled?: boolean;
            mode?: "time" | "date" | "month" | "year" | "decade";
            autofocus?: boolean;
            name?: string;
            placeholder?: string;
            transitionName?: string;
            dropdownClassName?: string;
            popupStyle?: import("vue").CSSProperties;
            defaultValue?: string | import("moment").Moment;
            allowClear?: boolean;
            suffixIcon?: import("../_util/type").VueNode;
            onOpenChange?: (status: boolean) => void;
            inputPrefixCls?: string;
            showToday?: boolean;
            defaultPickerValue?: string | import("moment").Moment;
            showTime?: boolean | Record<string, any>;
            disabledTime?: unknown;
            renderExtraFooter?: (mode: "time" | "date" | "month" | "year" | "decade") => any;
            onOk?: (selectedTime: import("moment").Moment) => void;
            onPanelChange?: (value: import("moment").Moment, mode: "time" | "date" | "month" | "year" | "decade") => void;
            format?: string | Function | string[];
            localeCode?: string;
            getCalendarContainer?: (triggerNode: Element) => HTMLElement;
            disabledDate?: (current: import("moment").Moment) => boolean;
            dateRender?: (current: import("moment").Moment, today: import("moment").Moment) => any;
            pickerClass?: string;
            pickerInputClass?: string;
            valueFormat?: string;
        }> & import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, "locale">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: import("vue").Slot;
        }>;
        $root: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>>;
        $parent: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>>;
        $emit: (event: string, ...args: any[]) => void;
        $el: any;
        $options: import("vue").ComponentOptionsBase<Readonly<{
            locale: any;
        } & {
            value?: string | import("moment").Moment;
            onFocus?: EventHandlerNonNull;
            onBlur?: EventHandlerNonNull;
            onChange?: (date: import("moment").Moment, dateString: string) => void;
            prefixCls?: string;
            size?: "default" | "small" | "large";
            open?: boolean;
            disabled?: boolean;
            mode?: "time" | "date" | "month" | "year" | "decade";
            autofocus?: boolean;
            name?: string;
            placeholder?: string;
            transitionName?: string;
            dropdownClassName?: string;
            popupStyle?: import("vue").CSSProperties;
            defaultValue?: string | import("moment").Moment;
            allowClear?: boolean;
            suffixIcon?: import("../_util/type").VueNode;
            onOpenChange?: (status: boolean) => void;
            inputPrefixCls?: string;
            showToday?: boolean;
            defaultPickerValue?: string | import("moment").Moment;
            showTime?: boolean | Record<string, any>;
            disabledTime?: unknown;
            renderExtraFooter?: (mode: "time" | "date" | "month" | "year" | "decade") => any;
            onOk?: (selectedTime: import("moment").Moment) => void;
            onPanelChange?: (value: import("moment").Moment, mode: "time" | "date" | "month" | "year" | "decade") => void;
            format?: string | Function | string[];
            localeCode?: string;
            getCalendarContainer?: (triggerNode: Element) => HTMLElement;
            disabledDate?: (current: import("moment").Moment) => boolean;
            dateRender?: (current: import("moment").Moment, today: import("moment").Moment) => any;
            pickerClass?: string;
            pickerInputClass?: string;
            valueFormat?: string;
        }>, {}, {}, import("vue").ComputedOptions, import("vue").MethodOptions, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, {
            locale: any;
        }>;
        $forceUpdate: import("vue").ReactiveEffect<any>;
        $nextTick: typeof import("vue").nextTick;
        $watch(source: string | Function, cb: Function, options?: import("vue").WatchOptions<boolean>): import("vue").WatchStopHandle;
    } & Readonly<{
        locale: any;
    } & {
        value?: string | import("moment").Moment;
        onFocus?: EventHandlerNonNull;
        onBlur?: EventHandlerNonNull;
        onChange?: (date: import("moment").Moment, dateString: string) => void;
        prefixCls?: string;
        size?: "default" | "small" | "large";
        open?: boolean;
        disabled?: boolean;
        mode?: "time" | "date" | "month" | "year" | "decade";
        autofocus?: boolean;
        name?: string;
        placeholder?: string;
        transitionName?: string;
        dropdownClassName?: string;
        popupStyle?: import("vue").CSSProperties;
        defaultValue?: string | import("moment").Moment;
        allowClear?: boolean;
        suffixIcon?: import("../_util/type").VueNode;
        onOpenChange?: (status: boolean) => void;
        inputPrefixCls?: string;
        showToday?: boolean;
        defaultPickerValue?: string | import("moment").Moment;
        showTime?: boolean | Record<string, any>;
        disabledTime?: unknown;
        renderExtraFooter?: (mode: "time" | "date" | "month" | "year" | "decade") => any;
        onOk?: (selectedTime: import("moment").Moment) => void;
        onPanelChange?: (value: import("moment").Moment, mode: "time" | "date" | "month" | "year" | "decade") => void;
        format?: string | Function | string[];
        localeCode?: string;
        getCalendarContainer?: (triggerNode: Element) => HTMLElement;
        disabledDate?: (current: import("moment").Moment) => boolean;
        dateRender?: (current: import("moment").Moment, today: import("moment").Moment) => any;
        pickerClass?: string;
        pickerInputClass?: string;
        valueFormat?: string;
    }> & import("vue").ShallowUnwrapRef<{}> & {} & {
        [x: string]: never;
    } & import("vue").MethodOptions & import("vue").ComponentCustomProperties;
    __isFragment?: never;
    __isTeleport?: never;
    __isSuspense?: never;
} & import("vue").ComponentOptionsBase<Readonly<{
    locale: any;
} & {
    value?: string | import("moment").Moment;
    onFocus?: EventHandlerNonNull;
    onBlur?: EventHandlerNonNull;
    onChange?: (date: import("moment").Moment, dateString: string) => void;
    prefixCls?: string;
    size?: "default" | "small" | "large";
    open?: boolean;
    disabled?: boolean;
    mode?: "time" | "date" | "month" | "year" | "decade";
    autofocus?: boolean;
    name?: string;
    placeholder?: string;
    transitionName?: string;
    dropdownClassName?: string;
    popupStyle?: import("vue").CSSProperties;
    defaultValue?: string | import("moment").Moment;
    allowClear?: boolean;
    suffixIcon?: import("../_util/type").VueNode;
    onOpenChange?: (status: boolean) => void;
    inputPrefixCls?: string;
    showToday?: boolean;
    defaultPickerValue?: string | import("moment").Moment;
    showTime?: boolean | Record<string, any>;
    disabledTime?: unknown;
    renderExtraFooter?: (mode: "time" | "date" | "month" | "year" | "decade") => any;
    onOk?: (selectedTime: import("moment").Moment) => void;
    onPanelChange?: (value: import("moment").Moment, mode: "time" | "date" | "month" | "year" | "decade") => void;
    format?: string | Function | string[];
    localeCode?: string;
    getCalendarContainer?: (triggerNode: Element) => HTMLElement;
    disabledDate?: (current: import("moment").Moment) => boolean;
    dateRender?: (current: import("moment").Moment, today: import("moment").Moment) => any;
    pickerClass?: string;
    pickerInputClass?: string;
    valueFormat?: string;
}>, {}, {}, import("vue").ComputedOptions, import("vue").MethodOptions, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, {
    locale: any;
}> & import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps & {
    readonly RangePicker: DefineComponent<RangePickerPropsTypes, {}, {}, import("vue").ComputedOptions, import("vue").MethodOptions, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
        locale: any;
    } & {
        value?: import("./interface").RangePickerValue;
        onFocus?: EventHandlerNonNull;
        onBlur?: EventHandlerNonNull;
        onChange?: (dates: import("./interface").RangePickerValue, dateStrings: [string, string]) => void;
        onMouseenter?: (e: MouseEvent) => void;
        onMouseleave?: (e: MouseEvent) => void;
        prefixCls?: string;
        size?: "default" | "small" | "large";
        open?: boolean;
        separator?: import("../_util/type").VueNode;
        disabled?: boolean;
        mode?: string | string[];
        autofocus?: boolean;
        name?: string;
        placeholder?: [string, string];
        transitionName?: string;
        dropdownClassName?: string;
        popupStyle?: import("vue").CSSProperties;
        defaultValue?: import("./interface").RangePickerValue;
        allowClear?: boolean;
        suffixIcon?: import("../_util/type").VueNode;
        onOpenChange?: (status: boolean) => void;
        inputPrefixCls?: string;
        showToday?: boolean;
        tagPrefixCls?: string;
        defaultPickerValue?: import("./interface").RangePickerValue;
        timePicker?: import("../_util/type").VueNode;
        showTime?: boolean | Record<string, any>;
        ranges?: import("./interface").RangePickerValue;
        disabledTime?: (current: import("./interface").RangePickerValue, type: string) => {
            disabledHours?: () => number[];
            disabledMinutes?: () => number[];
            disabledSeconds?: () => number[];
        };
        renderExtraFooter?: unknown;
        onCalendarChange?: (dates: import("./interface").RangePickerValue, dateStrings: [string, string]) => void;
        onOk?: (selectedTime: import("./interface").RangePickerPresetRange) => void;
        onPanelChange?: void;
        format?: string | Function | string[];
        localeCode?: string;
        getCalendarContainer?: (triggerNode: Element) => HTMLElement;
        disabledDate?: (current: import("moment").Moment) => boolean;
        dateRender?: (current: import("moment").Moment, today: import("moment").Moment) => any;
        pickerClass?: string;
        pickerInputClass?: string;
        valueFormat?: string;
    }>, {
        locale: any;
    }>;
    readonly MonthPicker: DefineComponent<MonthPickerPropsTypes, {}, {}, import("vue").ComputedOptions, import("vue").MethodOptions, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
        locale: any;
    } & {
        value?: string | import("moment").Moment;
        onFocus?: EventHandlerNonNull;
        onBlur?: EventHandlerNonNull;
        onChange?: (date: import("moment").Moment, dateString: string) => void;
        prefixCls?: string;
        size?: "default" | "small" | "large";
        open?: boolean;
        disabled?: boolean;
        autofocus?: boolean;
        name?: string;
        placeholder?: string;
        transitionName?: string;
        dropdownClassName?: string;
        popupStyle?: import("vue").CSSProperties;
        defaultValue?: string | import("moment").Moment;
        allowClear?: boolean;
        suffixIcon?: import("../_util/type").VueNode;
        onOpenChange?: (status: boolean) => void;
        inputPrefixCls?: string;
        defaultPickerValue?: string | import("moment").Moment;
        renderExtraFooter?: (mode: "time" | "date" | "month" | "year" | "decade") => any;
        format?: string | Function | string[];
        localeCode?: string;
        getCalendarContainer?: (triggerNode: Element) => HTMLElement;
        disabledDate?: (current: import("moment").Moment) => boolean;
        dateRender?: (current: import("moment").Moment, today: import("moment").Moment) => any;
        pickerClass?: string;
        pickerInputClass?: string;
        valueFormat?: string;
        monthCellContentRender?: (date: import("moment").Moment, locale: any) => any;
    }>, {
        locale: any;
    }>;
    readonly WeekPicker: DefineComponent<WeekPickerPropsTypes, {}, {}, import("vue").ComputedOptions, import("vue").MethodOptions, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
        locale: any;
    } & {
        value?: string | import("moment").Moment;
        onFocus?: EventHandlerNonNull;
        onBlur?: EventHandlerNonNull;
        onChange?: (date: import("moment").Moment, dateString: string) => void;
        prefixCls?: string;
        size?: "default" | "small" | "large";
        open?: boolean;
        disabled?: boolean;
        autofocus?: boolean;
        name?: string;
        placeholder?: string;
        transitionName?: string;
        dropdownClassName?: string;
        popupStyle?: import("vue").CSSProperties;
        defaultValue?: string | import("moment").Moment;
        allowClear?: boolean;
        suffixIcon?: import("../_util/type").VueNode;
        onOpenChange?: (status: boolean) => void;
        inputPrefixCls?: string;
        defaultPickerValue?: string | import("moment").Moment;
        renderExtraFooter?: (mode: "time" | "date" | "month" | "year" | "decade") => any;
        format?: string | Function | string[];
        localeCode?: string;
        getCalendarContainer?: (triggerNode: Element) => HTMLElement;
        disabledDate?: (current: import("moment").Moment) => boolean;
        dateRender?: (current: import("moment").Moment, today: import("moment").Moment) => any;
        pickerClass?: string;
        pickerInputClass?: string;
        valueFormat?: string;
    }>, {
        locale: any;
    }>;
} & Plugin;
export default _default;

==> ant-design-vue-2.1.6.jar: META-INF/resources/webjars/ant-design-vue/2.1.6/lib/date-picker/index.d.ts <==
import { DefineComponent, Plugin } from 'vue';
import { RangePickerPropsTypes, MonthPickerPropsTypes, WeekPickerPropsTypes } from './interface';
declare const _default: {
    new (...args: any[]): {
        $: import("vue").ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            locale: any;
        }> & Omit<Readonly<{
            locale: any;
        } & {
            value?: string | import("moment").Moment;
            onFocus?: EventHandlerNonNull;
            onBlur?: EventHandlerNonNull;
            onChange?: (date: import("moment").Moment, dateString: string) => void;
            prefixCls?: string;
            size?: "default" | "small" | "large";
            open?: boolean;
            disabled?: boolean;
            mode?: "time" | "date" | "year" | "month" | "decade";
            autofocus?: boolean;
            name?: string;
            placeholder?: string;
            transitionName?: string;
            dropdownClassName?: string;
            popupStyle?: import("vue").CSSProperties;
            defaultValue?: string | import("moment").Moment;
            allowClear?: boolean;
            suffixIcon?: import("../_util/type").VueNode;
            inputPrefixCls?: string;
            onOpenChange?: (status: boolean) => void;
            disabledDate?: (current: import("moment").Moment) => boolean;
            valueFormat?: string;
            onPanelChange?: (value: import("moment").Moment, mode: "time" | "date" | "year" | "month" | "decade") => void;
            format?: string | Function | string[];
            showToday?: boolean;
            defaultPickerValue?: string | import("moment").Moment;
            showTime?: boolean | Record<string, any>;
            disabledTime?: unknown;
            renderExtraFooter?: (mode: "time" | "date" | "year" | "month" | "decade") => any;
            onOk?: (selectedTime: import("moment").Moment) => void;
            localeCode?: string;
            getCalendarContainer?: (triggerNode: Element) => HTMLElement;
            dateRender?: (current: import("moment").Moment, today: import("moment").Moment) => any;
            pickerClass?: string;
            pickerInputClass?: string;
        }> & import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, "locale">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: import("vue").Slot;
        }>;
        $root: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>>;
        $parent: import("vue").ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, import("vue").ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>>;
        $emit: (event: string, ...args: any[]) => void;
        $el: any;
        $options: import("vue").ComponentOptionsBase<Readonly<{
            locale: any;
        } & {
            value?: string | import("moment").Moment;
            onFocus?: EventHandlerNonNull;
            onBlur?: EventHandlerNonNull;
            onChange?: (date: import("moment").Moment, dateString: string) => void;
            prefixCls?: string;
            size?: "default" | "small" | "large";
            open?: boolean;
            disabled?: boolean;
            mode?: "time" | "date" | "year" | "month" | "decade";
            autofocus?: boolean;
            name?: string;
            placeholder?: string;
            transitionName?: string;
            dropdownClassName?: string;
            popupStyle?: import("vue").CSSProperties;
            defaultValue?: string | import("moment").Moment;
            allowClear?: boolean;
            suffixIcon?: import("../_util/type").VueNode;
            inputPrefixCls?: string;
            onOpenChange?: (status: boolean) => void;
            disabledDate?: (current: import("moment").Moment) => boolean;
            valueFormat?: string;
            onPanelChange?: (value: import("moment").Moment, mode: "time" | "date" | "year" | "month" | "decade") => void;
            format?: string | Function | string[];
            showToday?: boolean;
            defaultPickerValue?: string | import("moment").Moment;
            showTime?: boolean | Record<string, any>;
            disabledTime?: unknown;
            renderExtraFooter?: (mode: "time" | "date" | "year" | "month" | "decade") => any;
            onOk?: (selectedTime: import("moment").Moment) => void;
            localeCode?: string;
            getCalendarContainer?: (triggerNode: Element) => HTMLElement;
            dateRender?: (current: import("moment").Moment, today: import("moment").Moment) => any;
            pickerClass?: string;
            pickerInputClass?: string;
        }>, {}, {}, import("vue").ComputedOptions, import("vue").MethodOptions, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, {
            locale: any;
        }>;
        $forceUpdate: import("vue").ReactiveEffect<any>;
        $nextTick: typeof import("vue").nextTick;
        $watch(source: string | Function, cb: Function, options?: import("vue").WatchOptions<boolean>): import("vue").WatchStopHandle;
    } & Readonly<{
        locale: any;
    } & {
        value?: string | import("moment").Moment;
        onFocus?: EventHandlerNonNull;
        onBlur?: EventHandlerNonNull;
        onChange?: (date: import("moment").Moment, dateString: string) => void;
        prefixCls?: string;
        size?: "default" | "small" | "large";
        open?: boolean;
        disabled?: boolean;
        mode?: "time" | "date" | "year" | "month" | "decade";
        autofocus?: boolean;
        name?: string;
        placeholder?: string;
        transitionName?: string;
        dropdownClassName?: string;
        popupStyle?: import("vue").CSSProperties;
        defaultValue?: string | import("moment").Moment;
        allowClear?: boolean;
        suffixIcon?: import("../_util/type").VueNode;
        inputPrefixCls?: string;
        onOpenChange?: (status: boolean) => void;
        disabledDate?: (current: import("moment").Moment) => boolean;
        valueFormat?: string;
        onPanelChange?: (value: import("moment").Moment, mode: "time" | "date" | "year" | "month" | "decade") => void;
        format?: string | Function | string[];
        showToday?: boolean;
        defaultPickerValue?: string | import("moment").Moment;
        showTime?: boolean | Record<string, any>;
        disabledTime?: unknown;
        renderExtraFooter?: (mode: "time" | "date" | "year" | "month" | "decade") => any;
        onOk?: (selectedTime: import("moment").Moment) => void;
        localeCode?: string;
        getCalendarContainer?: (triggerNode: Element) => HTMLElement;
        dateRender?: (current: import("moment").Moment, today: import("moment").Moment) => any;
        pickerClass?: string;
        pickerInputClass?: string;
    }> & import("vue").ShallowUnwrapRef<{}> & {} & {
        [x: string]: never;
    } & import("vue").MethodOptions & import("vue").ComponentCustomProperties;
    __isFragment?: never;
    __isTeleport?: never;
    __isSuspense?: never;
} & import("vue").ComponentOptionsBase<Readonly<{
    locale: any;
} & {
    value?: string | import("moment").Moment;
    onFocus?: EventHandlerNonNull;
    onBlur?: EventHandlerNonNull;
    onChange?: (date: import("moment").Moment, dateString: string) => void;
    prefixCls?: string;
    size?: "default" | "small" | "large";
    open?: boolean;
    disabled?: boolean;
    mode?: "time" | "date" | "year" | "month" | "decade";
    autofocus?: boolean;
    name?: string;
    placeholder?: string;
    transitionName?: string;
    dropdownClassName?: string;
    popupStyle?: import("vue").CSSProperties;
    defaultValue?: string | import("moment").Moment;
    allowClear?: boolean;
    suffixIcon?: import("../_util/type").VueNode;
    inputPrefixCls?: string;
    onOpenChange?: (status: boolean) => void;
    disabledDate?: (current: import("moment").Moment) => boolean;
    valueFormat?: string;
    onPanelChange?: (value: import("moment").Moment, mode: "time" | "date" | "year" | "month" | "decade") => void;
    format?: string | Function | string[];
    showToday?: boolean;
    defaultPickerValue?: string | import("moment").Moment;
    showTime?: boolean | Record<string, any>;
    disabledTime?: unknown;
    renderExtraFooter?: (mode: "time" | "date" | "year" | "month" | "decade") => any;
    onOk?: (selectedTime: import("moment").Moment) => void;
    localeCode?: string;
    getCalendarContainer?: (triggerNode: Element) => HTMLElement;
    dateRender?: (current: import("moment").Moment, today: import("moment").Moment) => any;
    pickerClass?: string;
    pickerInputClass?: string;
}>, {}, {}, import("vue").ComputedOptions, import("vue").MethodOptions, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, {
    locale: any;
}> & import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps & {
    readonly RangePicker: DefineComponent<RangePickerPropsTypes, {}, {}, import("vue").ComputedOptions, import("vue").MethodOptions, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
        locale: any;
    } & {
        value?: import("./interface").RangePickerValue;
        onFocus?: EventHandlerNonNull;
        onBlur?: EventHandlerNonNull;
        onChange?: (dates: import("./interface").RangePickerValue, dateStrings: [string, string]) => void;
        onMouseenter?: (e: MouseEvent) => void;
        onMouseleave?: (e: MouseEvent) => void;
        prefixCls?: string;
        size?: "default" | "small" | "large";
        open?: boolean;
        separator?: import("../_util/type").VueNode;
        disabled?: boolean;
        mode?: string | string[];
        autofocus?: boolean;
        name?: string;
        placeholder?: [string, string];
        transitionName?: string;
        dropdownClassName?: string;
        popupStyle?: import("vue").CSSProperties;
        defaultValue?: import("./interface").RangePickerValue;
        allowClear?: boolean;
        suffixIcon?: import("../_util/type").VueNode;
        inputPrefixCls?: string;
        onOpenChange?: (status: boolean) => void;
        disabledDate?: (current: import("moment").Moment) => boolean;
        valueFormat?: string;
        onPanelChange?: void;
        format?: string | Function | string[];
        showToday?: boolean;
        tagPrefixCls?: string;
        defaultPickerValue?: import("./interface").RangePickerValue;
        timePicker?: import("../_util/type").VueNode;
        showTime?: boolean | Record<string, any>;
        ranges?: import("./interface").RangePickerValue;
        disabledTime?: (current: import("./interface").RangePickerValue, type: string) => {
            disabledHours?: () => number[];
            disabledMinutes?: () => number[];
            disabledSeconds?: () => number[];
        };
        renderExtraFooter?: unknown;
        onCalendarChange?: (dates: import("./interface").RangePickerValue, dateStrings: [string, string]) => void;
        onOk?: (selectedTime: import("./interface").RangePickerPresetRange) => void;
        localeCode?: string;
        getCalendarContainer?: (triggerNode: Element) => HTMLElement;
        dateRender?: (current: import("moment").Moment, today: import("moment").Moment) => any;
        pickerClass?: string;
        pickerInputClass?: string;
    }>, {
        locale: any;
    }>;
    readonly MonthPicker: DefineComponent<MonthPickerPropsTypes, {}, {}, import("vue").ComputedOptions, import("vue").MethodOptions, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
        locale: any;
    } & {
        value?: string | import("moment").Moment;
        onFocus?: EventHandlerNonNull;
        onBlur?: EventHandlerNonNull;
        onChange?: (date: import("moment").Moment, dateString: string) => void;
        prefixCls?: string;
        size?: "default" | "small" | "large";
        open?: boolean;
        disabled?: boolean;
        autofocus?: boolean;
        name?: string;
        placeholder?: string;
        transitionName?: string;
        dropdownClassName?: string;
        popupStyle?: import("vue").CSSProperties;
        defaultValue?: string | import("moment").Moment;
        allowClear?: boolean;
        suffixIcon?: import("../_util/type").VueNode;
        inputPrefixCls?: string;
        onOpenChange?: (status: boolean) => void;
        disabledDate?: (current: import("moment").Moment) => boolean;
        valueFormat?: string;
        format?: string | Function | string[];
        defaultPickerValue?: string | import("moment").Moment;
        renderExtraFooter?: (mode: "time" | "date" | "year" | "month" | "decade") => any;
        localeCode?: string;
        getCalendarContainer?: (triggerNode: Element) => HTMLElement;
        dateRender?: (current: import("moment").Moment, today: import("moment").Moment) => any;
        pickerClass?: string;
        pickerInputClass?: string;
        monthCellContentRender?: (date: import("moment").Moment, locale: any) => any;
    }>, {
        locale: any;
    }>;
    readonly WeekPicker: DefineComponent<WeekPickerPropsTypes, {}, {}, import("vue").ComputedOptions, import("vue").MethodOptions, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
        locale: any;
    } & {
        value?: string | import("moment").Moment;
        onFocus?: EventHandlerNonNull;
        onBlur?: EventHandlerNonNull;
        onChange?: (date: import("moment").Moment, dateString: string) => void;
        prefixCls?: string;
        size?: "default" | "small" | "large";
        open?: boolean;
        disabled?: boolean;
        autofocus?: boolean;
        name?: string;
        placeholder?: string;
        transitionName?: string;
        dropdownClassName?: string;
        popupStyle?: import("vue").CSSProperties;
        defaultValue?: string | import("moment").Moment;
        allowClear?: boolean;
        suffixIcon?: import("../_util/type").VueNode;
        inputPrefixCls?: string;
        onOpenChange?: (status: boolean) => void;
        disabledDate?: (current: import("moment").Moment) => boolean;
        valueFormat?: string;
        format?: string | Function | string[];
        defaultPickerValue?: string | import("moment").Moment;
        renderExtraFooter?: (mode: "time" | "date" | "year" | "month" | "decade") => any;
        localeCode?: string;
        getCalendarContainer?: (triggerNode: Element) => HTMLElement;
        dateRender?: (current: import("moment").Moment, today: import("moment").Moment) => any;
        pickerClass?: string;
        pickerInputClass?: string;
    }>, {
        locale: any;
    }>;
} & Plugin;
export default _default;
